<?php
    require_once( "../sl_root.php" );
    chdir( ".." );
    require_once( "core/SLConfiguration.php" );
    require_once( "core/streamline_functions.php" );
    

    // Installation Type Test
    if ( is_file ( "config/db.conf.php" ) )
    {
        $db_conf_exists = true;
    }

    if ( $db_conf_exists )
    {
        require_once( "config/db.conf.php" );
        require_once( "core/db/connectors/$sl_db_type/SLDataBase.php" );

        $db = new SLDataBase( $sl_db_host, $sl_db_user, $sl_db_pass, $sl_db_name );
        $db_connected = $db->connect();
        
        if ( $db_connected )
        {
            require_once( "core/db/tables/SLConfigTable.php" );
            require_once( "core/SLConfigManager.php" );
        
            $table = new SLConfigTable( $db );
        
            $configManager = new SLConfigManager( $table );
            $config_loaded = $configManager->loadConfiguration();
        }

        if ( $config_loaded )
        {
            $config = $configManager->getConfiguration();
            
            $themes_exists = is_dir( $config->getThemesRoot() );
            $theme_exists = is_file( joinFilePath( joinFilePath( $config->getThemesRoot(), $config->getTheme() ), "layout.php" ) );
            $mp3_root_exists = is_dir( $config->getMediaRoot() );

            $streamFormat = "";
            $array = $config->getStreamFormat();
            $streamFormat = implode( "", $array );

            $browseFormat = "";
            $array = $config->getBrowseFormat();
            $browseFormat = implode( "", $array );

            $sortOrder = "";
            $array = $config->getSortOrder();
            $sortOrder = implode( ", ", $array );
        }
    }


    $htaccess_exists = is_file( "music/.htaccess" );
    
    if ( $htaccess_exists )
    {
        $lines = file( "music/.htaccess" );
        $ed = "ErrorDocument 404";
        $len = strlen( $ed );
        foreach( $lines as $line )
        {
            if ( substr( $line, 0, $len ) == $ed )
            {
                $set_doc = trim( substr( $line, $len, ( strlen( $line ) - $len - 1 ) ) );
                //$doc = dirname( trim( substr( $line, $len, ( strlen( $line ) - $len - 1 ) ) ) );
                break;
            }
        }

        if ( isset( $_SERVER['REQUEST_URI'] ) )
        {
            $uri = stripslashes( $_SERVER['REQUEST_URI'] );
            $index = strpos( $uri, "admin/test_config.php" );
            $root = substr( $uri, 0, $index  );
            $good_doc = $root."music/index.php";
        }

        
        $err_doc_correct = $set_doc == $good_doc;
    }
    
    chdir( "admin" );
    require_once( "admin.header.php" );
?>
          <!-- Start Admin Body -->
          <h2 style="border-bottom: solid 1px black; padding-top: 20px">Streamline Configuration Tester</h2>
          
          <p><strong>Installation Intergrity Tests:</strong></p>
          <div style="padding-left: 15px" >
            <table bgcolor="#FFFFFF" cellpadding="3" style="border: solid 1px black">
              <tr bgcolor="#CCCCCC"><td><strong>Test</strong></td><td><strong>Result</strong></td></tr>
              <tr bgcolor="#CCCCCC"><td>'config/db.conf.php' exists: </td><td align="center"><?php echo $db_conf_exists?"yes":"no"; ?></td></tr>
              <tr bgcolor="#CCCCCC"><td>Connected to Database: </td><td align="center"><?php echo $db_conf_exists?"yes":"no"; ?></td></tr>
              <tr bgcolor="#CCCCCC"><td>Config Loaded: </td><td align="center"><?php echo $config_loaded?"yes":"no"; ?></td></tr>
              <tr bgcolor="#CCCCCC"><td>.htaccess file exists: </td><td align="center"><?php echo $htaccess_exists?"yes":"no"; ?></td></tr>
              <tr bgcolor="#CCCCCC"><td>ErrorDocument path correct: </td><td align="center"><?php echo $err_doc_correct?"yes":"no"; ?></td></tr>
              <tr bgcolor="#CCCCCC"><td>Themes Root exists: </td><td align="center"><?php echo $themes_exists?"yes":"no"; ?></td></tr>
              <tr bgcolor="#CCCCCC"><td>Theme exists: </td><td align="center"><?php echo $theme_exists?"yes":"no"; ?></td></tr>
            </table>
          </div>
          
          <p><strong>Streamline Configuration Evaluation:</strong></p>
          <div style="padding-left: 15px" >
            <table bgcolor="#FFFFFF" cellpadding="3" style="border: solid 1px black">
              <tr bgcolor="#CCCCCC">
                <td><strong>Option</strong></td><td><strong>Value</strong></td><td><strong>Valid</strong></td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>WebServerRoot</td><td><?php echo $config->getWebServerRoot(); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>Mp3ServerRoot</td><td><?php echo $config->getMediaServerRoot(); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>Mp3Root</td><td><?php echo $config->getMediaRoot(); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>ThemesRoot</td><td><?php echo $config->getThemesRoot(); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>Thems</td><td><?php echo $config->getTheme(); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>ProtectBrowsing</td><td><?php echo ($config->getProtectBrowsing()?"yes":"no"); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>ProtectStreaming</td><td><?php echo ($config->getProtectStreaming()?"yes":"no"); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>ProtectDownloading</td><td><?php echo ($config->getProtectDownloading()?"yes":"no"); ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>BrowseFormat</td><td><?php echo $browseFormat; ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>StreamFormat</td><td><?php echo $streamFormat; ?></td><td align="center">yes</td>
              </tr>
              <tr bgcolor="#CCCCCC">
                <td>SortOrder</td><td><?php echo $sortOrder; ?></td><td align="center">yes</td>
              </tr>
          </table>
        </div>
        </p>
        <a class="admin_link" href="index.php">Back to Admin Home</a>
<?php
    $_SESSION[SL_CONFIG] = null;
    require_once( "admin.footer.php" );
?>
