<?
require_once( "SLConfiguration.php" );
require_once( "db/tables/SLConfigTable.php" );

if ( !defined( "SL_CONFIG_MANAGER" ) ){
      define( "SL_CONFIG_MANAGER", 1 );
    
    class SLConfigManager 
    {
        var $table;
        var $config;
        
        function SLConfigManager( $config_table )
        {
            $this->table = $config_table;
        }
        
        function loadConfiguration()
        {
            $this->config = new SLConfiguration();
            $result = false;
            
            $options = $this->table->getAllOptions();

            if ( is_array( $options ) )
            {

                foreach( $options as $option )
                {
                    $name = $option->getName();
                    $value = $option->getValue();
                
                    $this->setConfigValue( $name, $value );
                }

                $result = true;
            }
            
            return $result;
        }
    
        function setConfigValue( $key, $value )
        {
           $value = $this->processValue( $value ); 
            
            switch ( $key )
            {
                case SL_MEDIA_SERVER_ROOT:
                    $value = $this->processPath( $value );
                    $this->config->setMediaServerRoot( $value  );
                    break;
                    
                case SL_WEB_SERVER_ROOT:
                    $value = $this->processPath( $value );
                    $this->config->setWebServerRoot( $value  );
                    break;
            
                case SL_MEDIA_ROOT:
                    $value = $this->processPath( $value );
                    $this->config->setMediaRoot( $value );
                    break;

                case SL_THEME:
                    $this->config->setTheme( $value );
                    break;
                
                case SL_SERVER_TITLE:
                    $this->config->setServerTitle( $value );
                    break;
                
                case SL_BROWSING_REQUIRES_AUTH:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setBrowsingRequiresAuth( $bool );
                    break;
                
                case SL_STREAMING_REQUIRES_AUTH:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setStreamingRequiresAuth( $bool );
                    break;
                
                case SL_DOWNLOADING_REQUIRES_AUTH:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setDownloadingRequiresAuth( $bool );
                    break;
                                
                case SL_ADMIN_REQUIRES_AUTH:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setAdminRequiresAuth( $bool );
                    break;

                case SL_BROWSER_COLUMNS:
                    $this->config->setBrowserColumns( $value );
                    break;
                
                case SL_STREAM_FORMAT:
                    $this->config->setStreamFormat( $value );
                    break;
                
                case SL_SORT_ORDER:
                    $this->config->setSortOrder( $value );
                    break;
                
                case SL_BROWSE_HAC_DEFAULT:
                    $this->config->setBrowseHACDefault( $value );
                    break;
                
                case SL_STREAM_HAC_DEFAULT:
                    $this->config->setStreamHACDefault( $value );
                    break;
                
                case SL_DOWNLOAD_HAC_DEFAULT:
                    $this->config->setDownloadHACDefault( $value );
                    break;
                
                case SL_GLOBAL_HAC_DEFAULT:
                    $this->config->setGlobalHACDefault( $value );
                    break;
                
                case SL_BROWSE_HAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setBrowseHACEnabled( $bool );
                    break;
                
                case SL_STREAM_HAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setStreamHACEnabled( $bool );
                    break;
                
                case SL_DOWNLOAD_HAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setDownloadHACEnabled( $bool );
                    break;
                
                case SL_GLOBAL_HAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setGlobalHACEnabled( $bool );
                    break;

                case SL_BROWSE_AAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setBrowseAACEnabled( $bool );
                    break;
                
                case SL_STREAM_AAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setStreamAACEnabled( $bool );
                    break;
                
                case SL_DOWNLOAD_AAC_ENABLED:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setDownloadAACEnabled( $bool );
                    break;

                case SL_BROWSE_AAC_MODE:
                    $this->config->setBrowseAACMode( $value );
                    break;
                
                case SL_STREAM_AAC_MODE:
                    $this->config->setStreamAACMode( $value );
                    break;
                
                case SL_DOWNLOAD_AAC_MODE:
                    $this->config->setDownloadAACMode( $value );
                    break;

                case SL_LOG_BROWSE:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setLogBrowsing( $bool );
                    break;
                
                case SL_LOG_STREAM:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setLogStreaming( $bool );
                    break;
                
                case SL_LOG_DOWNLOAD:
                    $bool = $this->processBooleanValue( $value );
                    $this->config->setLogDownloading( $bool );
                    break;
                
                default:
                    return;
            }
            
        }

        function processBooleanValue( $value )
        {
            $bool_str = strtoupper( $value );
            return ( $bool_str == "TRUE" || $bool_str == "YES"  || $bool_str == "1" );
        }

        
        function processPath( $path )
        {
            if ( $path{ strlen( $path ) - 1 } != '/' )
            {
                $path."/";
            }

            return $path;
        }
        
        
        function processValue( $value )
        {
            $value = trim( $value );

            if ( $value{0} == '"' )
            {
                $value = substr( $value, 1, strlen( $value ) - 2 );

                if ( $value{ strlen( $value ) - 1 } == '"' )
                {
                    $value = substr( $value, 0, strlen( $value ) - 2 );
                }
            }

            return $value;
        }
        
        function getConfiguration()
        {
            return $this->config;
        }
    }
}
?>
