<?
    require_once( "Authenticator.php" );
    
    // 
    // This method will see if a user is already logged in.  If not
    // it will take the specified action to request login info.
    //
    function handleLogin( $http_auth, $db, $server_root = "" )
    {
        $auther = new Authenticator();
        $logged_in = $auther->isLoggedIn();

        // If the user is already logged in attempt to valid the user and 
        // password.  If they are not valid, clear the login info.
        if ( $logged_in )
        {
            $auth_valid = $auther->validateUser( $db );

            if ( !$auth_valid )
            {
                $auther->logout();
                $logged_in = false;
            }
        }
        
        // If the user wasn't "logged in" in the first place or they were
        // logged out because of a user/pass missmatch we will attempt to log
        // them in.
        if ( !$logged_in ) 
        {
            
            $new_uname = "";
            $new_pass = "";
            
            // We have two places we can get the auth info from.  Either HTTP
            // headers if it is HTTP Auth, or Request data if the login is
            // from the php form.
            
            if ( $http_auth )
            {
                $new_uname = array_key_exists( "PHP_AUTH_USER", $_SERVER )?$_SERVER['PHP_AUTH_USER']:null;
                $new_pass = array_key_exists( "PHP_AUTH_PW", $_SERVER )?$_SERVER['PHP_AUTH_PW']:null;
            }
            else 
            {
                $new_uname = array_key_exists( 'SL_AUTH_USER', $_REQUEST )?$_REQUEST['SL_AUTH_USER']:null;
                $new_pass = array_key_exists( 'SL_AUTH_PW', $_REQUEST )?$_REQUEST['SL_AUTH_PW']:null;
            }

            // Attempt to validate the user based on the username and password
            // we got above.
            $valid = $auther->login( $new_uname, $new_pass, $db );

            // If they are not valid then we see if they are over the max login
            // tries and either boot them or ask them to log in again.
            if ( !$valid )
            {
                
                if ( isset( $new_uname ) || isset( $new_pass ) )
                {
                    $_SESSION[SL_LOGIN_FAILED] = true;
                }
                
                $max = overMaxLoginTries();

                if ( $max )
                {
                    header( "Location: ".$server_root."weblogin/unauthorized.php" );
                    echo "\n";
                    exit();
                }
                else
                {
                    $http_auth?doHTTPLogin():doPHPLogin($server_root);
                }
            }
            else 
            {
                if ( !$http_auth )
                {
                    $_SESSION[SL_LOGIN_FAILED] = false;

                    // Handle Setting The Cookie
                    $remember_login = array_key_exists( 'SL_REMEMBER_LOGIN', $_REQUEST )?$_REQUEST['SL_REMEMBER_LOGIN'] == "on":false;
                    if ( $remember_login )
                    {
                        global $sl_config;

                        $cookie = "$new_uname:$new_pass";
                        $cookie = ~$cookie;
                        $cookie = base64_encode( $cookie );
                        setcookie("SL_AUTH_COOKIE", $cookie, time()+60*60*24*30, $sl_config->getMediaServerRoot() );
                    }
                    
                    // If this was not http auth, then the user probably got
                    // redirected to the login page and we want to send them
                    // back to where they really wanted to go.
                    
                    $uri = $_SESSION[SL_CURRENT_URI];
                    if ( strlen( $uri ) <= 0 )
                    {
                        $uri = $server_root;
                    }
                    $_SESSION[SL_LOGIN_TRIES] = 0;
                    
                    header( "Location: $uri" );
                    echo "\n";
                }
            }
        }
    }
   
   
    //
    // This method tells us if the user is over the maximum number of login
    // tries.
    //
    function overMaxLoginTries()
    {
        $result = true;
        
        if ( !isset( $_SESSION[SL_LOGIN_TRIES] ) )
        {
            $_SESSION[SL_LOGIN_TRIES] = 1;
            $result = false;
        }
        else if ( $_SESSION[SL_LOGIN_TRIES] < 3 )
        {
            $_SESSION[SL_LOGIN_TRIES] = $_SESSION[SL_LOGIN_TRIES] + 1;
            $result = false;
        }
        else
        {
            $_SESSION[SL_LOGIN_TRIES] = 0;
        }

        return $result;
    }


    // 
    // Perform a PHP Login (i.e. redirect to the login form).
    //
    function doPHPLogin( $server_root )
    {
        header( "Location: ".$server_root."weblogin/loginform.php" );
        echo "\n";
        exit();
    }
    

    //
    // Perform a HTTP Loging (send back the 401 header).
    //
    function doHTTPLogin()
    {
        global $sl_config;
        $title = $sl_config->getServerTitle();
        header( "WWW-Authenticate: Basic realm=\"$title\"" );
        header( 'HTTP/1.0 401 Unauthorized' );
        echo "\n";
        exit;
    }
?>
