<?php
require_once( "core/streamline_functions.php" );
require_once( "core/MediaSorter.php" );
require_once( "core/browser/SLMediaInfo.php" );

if ( !defined( "_SL_DIR_EXPLORER" ) ){
      define( "_SL_DIR_EXPLORER", 1 );
    
        
    class SLDirExplorer
    {
        var $dir;
        
        var $all_entries;
        var $files_only;
        var $dirs_only;
        
        var $media_server_root;
        var $media_root;

        var $id3_cache;

        
        function SLDirExplorer( $dir, $sl_config, $sl_media_info_cache )
        {
            $this->dir = $dir;
            $this->sort_order = $sl_config->getSortOrder();
            $this->media_server_root = $sl_config->getMediaServerRoot();
            $this->media_root = $sl_config->getMediaRoot();
            $this->id3_cache = $sl_media_info_cache;
        }


        function getDir()
        {
            return $this->dir;
        }

        
        function isDirectoryBrowseable()
        {
            $result = true;
            $dir = $this->media_root.$this->dir;
            
            $result = is_dir( $dir );

            return $result;
        }
        
        function traverseDirectory()
        {
            $dir = $this->media_root.$this->dir;

            if ( $dir{ strlen( $dir ) - 1 } != '/' ) 
            {
                $dir = $dir."/";
            }
            
            $all = array ();
            $files = array();
            $dirs = array();
            
            $handle=opendir($dir);
          
            /* This is the correct way to loop over the directory. */
            while (false !== ( $file = readdir($handle) ) ) 
            {
                if( $file == "." || $file == ".." )
                {
                    continue;;
                }
                                  
                array_push( $all, $file );

                if ( is_dir( $dir.$file ) )
                {
                    array_push( $dirs, $file );
                }
                else if ( is_file( $dir.$file ) )
                {
                    $tmp = explode( ".", $file );
                    $ext = array_pop( $tmp );
                    $ext = strtolower( $ext );
                   
                    global $sl_media_types;
                    
                    if ( array_key_exists( $ext, $sl_media_types ) )
                    {
                        array_push( $files, $file );
                    }
                }
            }

            sort( $all );
            $sorter = new MediaSorter( $this->dir, $files, $this->sort_order, $this->id3_cache );
            $files = $sorter->sortMedia();

            $this->files_only = array();
            
            foreach ( $files as $file )
            {
                $media_path = joinFilePath( $this->dir, $file ); 
                $tag = $this->id3_cache->getMediaInfo( $media_path );
                $web_path = createWebPath( $media_path );
                array_push( $this->files_only, new SLMediaInfo( $this->media_server_root, $web_path, $tag  ) );
            }
            sort( $dirs );
  
            closedir($handle);

            $this->all_entries = $all;
            $this->dirs_only = $dirs;
        }

        function getNumFiles()
        {
            return count( $this->files_only );
        }

        function & getFiles()
        {
            return $this->files_only;
        }

        function getNumDirs()
        {
            return count( $this->dirs_only );
        }

        function & getDirs()
        {
            return $this->dirs_only;
        }
        
    }
}
?>
