<?php
require_once( "core/streamline_functions.php" );

if ( !defined( "_SL_MEDIA_TABLE_GEN" ) ){
      define( "_SL_MEDIA_TABLE_GEN", 1 );

    class SLMediaTableGen
    {
        var $media_array;
        var $media_server_root;
        var $columns;
        var $stream_access;
        var $dl_access;
        var $theme_path;
        
        function SLMediaTableGen( &$media_array, $columns, $media_server_root, &$access_controler )
        {
            $this->media_array = &$media_array;
            $this->media_server_root = $media_server_root;
            $this->columns = $columns;
            $this->stream_access = $access_controler->getStreamAccess();
            $this->dl_access  = $access_controler->getDownloadAccess();
            global $sl_cur_theme;
            $this->theme_path = $sl_cur_theme->getWebPath();
        }

        function generateTable( $title )
        {
            $this->startTable( $title );
            $this->outputTableHeader();
            $this->outputTableBody();
            $this->endTable();
        }
        
        function startTable( $title )
        {
            outputHTMLLine( "<table class=\"sl_browser_table\">" );
        }
        
        function outputTableHeader()
        {

            outputHTMLLine( "<tr>" );
            foreach( $this->columns as $column )
            {
                $title = $this->getColumnTitle( $column );
                outputHTMLLine( "<th class=\"sl_browser_header\">$title</th>" );
            }

            $cols = 1;
            
            if ( $this->stream_access || $this->dl_access )
            {
                if ( $this->stream_access )
                {
                    $cols = $cols + 2;
                }

                if ( $this->dl_access )
                {
                    $cols = $cols + 1;
                }

            }
            outputHTMLLine( "<th class=\"sl_browser_header\" colspan=\"$cols\">Actions</th>" );
            outputHTMLLine( "</tr>" );
        }

        function outputTableBody()
        {
            $images_path = joinURLPath( $this->theme_path, "images" );
            
            $row_count = 0;
            
            foreach ( $this->media_array as $m_info )
            {
                $row_count++;

                $tag = $m_info->getInfo();
                $rel_path = htmlspecialchars( $m_info->getRelativePath() );
                $info_path = htmlspecialchars( $m_info->getInfoPath() );
                $m3u_path = htmlspecialchars( $m_info->getM3UPath() );
                $dl_path = htmlspecialchars( $m_info->getDownloadPath() );

                if ( $row_count % 2 == 0 )
                {
                    outputHTMLLine( "<tr class=\"sl_browser_even_row\">" );
                }
                else
                {
                    outputHTMLLine( "<tr class=\"sl_browser_odd_row\">" );
                }

                // Track Info
                
                foreach( $this->columns as $column )
                {
                    $value = $this->getColumnValue( $tag, $column );
                    outputHTMLLine( "<td class='sl_browser_file' align=\"left\">".$value."</td>" );
                }
                
                if ( $this->stream_access )
                {
                    // Stream Link
                    outputHTMLLine( "<td width=\"1%\" class='sl_browser_action'>".
                        "<a title=\"Stream '".htmlspecialchars($tag->getTitle()).
                        "'\" href=\"$m3u_path\"><img border=0 src=\"$images_path/stream.png\" alt=\"Stream\"></a></td>" );


                    // Playlist Link
                    $media_server_root = $this->media_server_root;
                    outputHTMLLine( "<td width=\"1%\" class='sl_browser_action'>".
                        "<a title=\"Add '".htmlspecialchars($tag->getTitle()).
                        "' to Current Playlist\" href=\"#\"><img onClick=\"AddWindow=".
                        "window.open('$media_server_root/home/playlists/add_media.php?media=".
                        rawurlencode( $rel_path )."&amp;title=".rawurlencode( $tag->getTitle() )."','AddToList',".
                        "'toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=no,resizable=yes,width=350,height=150');".
                        "AddWindow.focus(); return false;\" border=0 src=\"$images_path/playlist_add.png\" alt=\"Playlist Add\"></a></td>" );
                }
               
                if ( $this->dl_access )
                {
                // d/l Link
                outputHTMLLine( "<td width=\"1%\" class='sl_browser_action'>".
                    "<a title=\"Download '".htmlspecialchars($tag->getTitle()).
                    "'\" href=\"$dl_path\"><img border=0 src=\"$images_path/download.png\" alt=\"Download\"></a></td>" );
                }
               

                // info Link
//                outputHTMLLine( "<td width=\"1%\" class='sl_browser_action'>".
//                    "<a title=\"View Info for '".htmlspecialchars($tag->getTitle())."'\" href=\"#\">".
//                    "<img onClick=\"Info=window.open('$info_path','StreamlineMediaInfo',".
//                    "'toolbar=no,location=no,directories=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=425,height=400');".
//                    "return false;\"border=0 src=\"$images_path/media-info.png\" alt=\"Info\"></a></td>" );

                outputHTMLLine(
                    "<td width=\"1%\" class='sl_browser_action'>".
                    "<a title=\"View Info for '".htmlspecialchars($tag->getTitle())."'\" href=\"$info_path\">".
                    "<img border=0 src=\"$images_path/media-info.png\" alt=\"Info\"></a>" );
                
                outputHTMLLine( "</tr>" );
                
            }
        
        }

        function endTable()
        {
            outputHTMLLine( "</table>" );
        }

        function getColumnValue( $tag, $att )
        {
            $result = "";

            switch( $att )
            {
                case "artist":
                    $result = $tag->getArtist();
                    break;
                    
                case "title":
                    $result = $tag->getTitle();
                    if ( strlen( $result ) < 1 )
                    {
                        $result = $tag->getFileName();
                    }
                    break;
                    
                case "album":
                    $result = $tag->getAlbum();
                    break;
                    
                case "track":
                    $result = $tag->getTrack();
                    break;
                    
                case "genre":
                    $result = $tag->getGenre();
                    break;
                    
                default:
                    break;
            }

            return $result;
                    
        }

        function getColumnTitle( $att )
        {
            $result = "";

            switch( $att )
            {
                case "artist":
                    $result = "Artist";
                    break;
                    
                case "track":
                    $result = "Track";
                    break;
                    
                case "title":
                    $result = "Title";
                    break;
                    
                case "album":
                    $result = "Album";
                    break;
                    
                case "genre":
                    $result = "Genre";
                    break;
                    
                default:
                    break;
            }

            return $result;
                    
        }
    }
}
?>
