<?php

require_once( "core/db/objects/SLDailyStats.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_DAILY_STATS_TABLE" ) ){
      define( "_SL_DAILY_STATS_TABLE", 1 );

    class SLDailyStatsTable 
    {
        var $db;

        function SLDailyStatsTable( $db )
        {
            $this->db = $db;
        }

        
        function createDailyStats( $date  )
        {
            $template = "INSERT INTO stats_daily ( date, browses, streams, downloads ) VALUES ( ?, 0, 0, 0 )";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $date );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteDailyStats( $date )
        {
            $template = "DELETE FROM stats_daily WHERE date = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $date );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
       

        function deleteEntriesOlderThanTime( $time )
        {
            $template = "DELETE FROM stats_daily WHERE date < ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $time );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        

        function getStatsForDay( $date )
        {
            $result = null;
            
            $template = "SELECT date FROM stats_daily WHERE date = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $date );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLDailyStats( $this->db, $rows[0]['date'] );
                }
            }

            return $result;
        }


        function statsExistForDay( $date )
        {
            $result = false;
            $date = strtotime( date( "d F Y" ) ); 
            
            $template = "SELECT date FROM stats_daily WHERE date = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $date );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                $result = is_array( $rows ) && count( $rows ) > 0;
            }
            
            return $result; 
        }
            
        
        function getStatsForRangeOfTime( $start_time, $end_time )
        {
            $result = false;
            
            $template = "SELECT date FROM stats_daily WHERE date >= ? AND date <= ? ORDER BY date";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $start_time );
            $sql->setValue( 1, $end_time );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLDailyStats( $this->db, $row['date'] ) );
                }    
            }
            
            return $result;
        }
    }
}
?>
