<?php

require_once( "core/db/objects/SLDownloadLog.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_DOWNLOAD_LOG_TABLE" ) ){
      define( "_SL_DOWNLOAD_LOG_TABLE", 1 );

    class SLDownloadLogTable
    {
        var $db;

        function SLDownloadLogTable( $db )
        {
            $this->db = $db;
        }

        
        function addLogEntry( $host, $user, $media )
        {
            $template ="INSERT INTO downloadlog (time, host, uname, media) VALUES (?, ?, ?, ?)";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, time() );
            $sql->setValue( 1, $host );
            $sql->setValue( 2, $user );
            $sql->setValue( 3, $media );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteAllEntries()
        {
            $sql = "DELETE FROM downloadlog WHERE 1";
            
            $result = $this->db->query( $sql );
            return $result;
        }
        
        function deleteEntriesOlderThanTime( $time )
        {
            $template = "DELETE FROM downloadlog WHERE time < ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $time );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        
        function getNumberOfRows()
        {
            $result = 0;
            
            $qr = $this->db->query( "SELECT COUNT(logid) from downloadlog" );
            if ( $qr )
            {
                $last = $this->db->getLastResult();
                $result = array_pop( $last[0] );
            }
            else
            {
                $result = -1;
            }
            
            return $result;
        }


        function getNumberOfEntriesForUser( $uname )
        {
            $result = 0;
            
            $template = "SELECT COUNT(logid) from downloadlog WHERE uname = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uname );
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $last = $this->db->getLastResult();
                $result = array_pop( $last[0] );
            }
            else
            {
                $result = -1;
            }
            
            return $result;
           
        }


        function getLogEntryRangeForUser( $uname, $num_per_page, $start )
        {
            $result = array();

            $template = "SELECT logid FROM downloadlog WHERE uname = ? ORDER BY time DESC LIMIT ? OFFSET ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uname );
            $sql->setValue( 1, $num_per_page );
            $sql->setValue( 2, $start );
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $rows = $this->db->getLastResult(); 
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLDownloadLog( $this->db, $row['logid'] ) );
                }
            }
            
            return $result;
        }


        function getLogEntryRange( $num_per_page, $start )
        {
            $result = array();

            $template = "SELECT logid FROM downloadlog ORDER BY time DESC LIMIT ? OFFSET ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $num_per_page );
            $sql->setValue( 1, $start );
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $rows = $this->db->getLastResult(); 
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLDownloadLog( $this->db, $row['logid'] ) );
                }
            }
            
            return $result;
        }

        
        function getAllLogEntries()
        {
            $result = array();
            $qr = $this->db->query( "SELECT logid FROM downloadlog" );
            if ( $qr )
            {
                $rows = $this->db->getLastResult(); 
                foreach( $rows as $row )
                {
                    array_push( $result, new SLDownloadLog( $this->db, $row['logid'] ) );
                }
            }
            
            return $result;
        }
    }
}
?>
