<?php

require_once( "core/db/objects/SLMediaType.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_MEDIA_TYPE_TABLE" ) ){
      define( "_SL_MEDIA_TYPE_TABLE", 1 );

    class SLMediaTypeTable
    {
        var $db;

        function SLMediaTypeTable( $db )
        {
            $this->db = $db;
        }

        
        function createMediaType( $extension, $description, $icon, $enabled )
        {
            $template = "INSERT INTO media_type (extension, description, icon, enabled ) VALUES ( ?, ?, ?, ? )";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $extension );
            $sql->setValue( 1, $description );
            $sql->setValue( 2, $icon );
            $sql->setValue( 3, $enabled );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteMediaTypeByExtension( $extension )
        {
            $template ="DELETE FROM media_type where extension = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $extension );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        

        function deleteAllMediaTypes()
        {
            $this->db->query( "DELETE FROM media_type where 1" );
        }
        
        
        function getAllMediaTypes()
        {
            $result = array();
            $qr = $this->db->query( "SELECT extension FROM media_type WHERE 1" );
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    foreach( $rows as $row )
                    {
                        $result[] = new SLMediaType( $this->db, $row['extension'] );
                    }
                }
            }

            return $result;
        }

        function getEnabledMediaTypes()
        {
            $result = array();
            $qr = $this->db->query( "SELECT extension FROM media_type WHERE enabled=1" );
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    foreach( $rows as $row )
                    {
                        $result[] = new SLMediaType( $this->db, $row['extension'] );
                    }
                }
            }

            return $result;
        }

        function getDisabledMediaTypes()
        {
            $result = array();
            $qr = $this->db->query( "SELECT extension FROM media_type WHERE enabled=0" );
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    foreach( $rows as $row )
                    {
                        $result[] = new SLMediaType( $this->db, $row['extension'] );
                    }
                }
            }

            return $result;
        }
       
       
        function getMediaTypeByExtension( $extension )
        {
            $result = null;

            $template = "SELECT extension FROM media_type WHERE extension = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $extension );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLMediaType( $this->db, $rows[0]['extension'] );
                }
            }

            return $result;
        }

        function setEnabledMediaTypes( $types )
        {
            $where_clause = "(";
      
            foreach( $types as $type )
            {
                if ( $where_clause != "(" )
                {
                    $where_clause .= " OR ";
                }
                
                $where_clause .= "extension = ?";
            }

            $where_clause .= ")";

            $where = SQLStatement::createStatement( $where_clause );
            
            $count = count( $types );
            
            for ( $i = 0; $i < $count; $i++ )
            {
                $where->setValue( $i, $types[$i] );
            }

            $where_sql = $where->toSQL();
            
            $sql1 = "UPDATE media_type set enabled = 1 WHERE $where_sql";
            $sql2 = "UPDATE media_type set enabled = 0 WHERE NOT $where_sql";

            $result = $this->db->query( $sql1 );
            $result = $this->db->query( $sql2 );

            return $result;
        }
    }
}
?>
