<?php

require_once( "core/db/objects/SLPlayList.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_PLAY_LIST_TABLE" ) ){
      define( "_SL_PLAY_LIST_TABLE", 1 );

    class SLPlayListTable
    {
        var $db;

        function SLPlayListTable( $db )
        {
            $this->db = $db;
        }

        
        function createPlayList( $uid, $title )
        {
            $template = "INSERT INTO playlists ( uid, title ) VALUES ( ?, ? )";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            $sql->setValue( 1, $title );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }


        function deletePlayList( $listid )
        {
            require_once( "core/db/tables/SLPLEntryTable.php" );
            $plentry_table = &new SLPLEntryTable( $this->db );
            
            // First we delete any entries that belong to this list.
            $plentry_table->deletePLEntriesForListID( $listid );
            
            // After the lists entries are gone then we can delete the
            // list itself.
            $template = "DELETE FROM playlists WHERE listid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $listid );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }
        
        
        function removeListsForUIDsNot( $uids )
        {
            $where_clause = "(";
            
            $count = count( $uids );
      
            for ( $i = 0; $i < $count; $i++ )
            {
                if ( $where_clause != "(" )
                {
                    $where_clause .= " OR ";
                }
                
                $where_clause .= "uid = ?";
            }

            $where_clause .= ")";

            $where = SQLStatement::createStatement( $where_clause );
            
            for ( $i = 0; $i < $count; $i++ )
            {
                $where->setValue( $i, $uids[$i] );
            }

            $where_sql = $where->toSQL();
            $sql = "DELETE FROM playlists WHERE NOT $where_sql";
            $result = $this->db->query( $sql );

            return $result;
        }
        
        function getPlayListByTitleForUserID( $title, $uid )
        {
            $result = null;
            
            $template = "SELECT listid FROM playlists WHERE uid = ? AND title = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            $sql->setValue( 1, $title );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                $result =  new SLPlayList( $this->db, $rows[0]['listid'] );
            }

            return $result;
        }
       

        function getPlayListsByUserID( $uid )
        {
            $result = null;
            
            $template = "SELECT listid FROM playlists WHERE uid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLPlayList( $this->db, $row['listid'] ) );
                }    
            }

            return $result;
        }

        function getPlayListById( $listid )
        {
            $template = "SELECT listid FROM playlists where listid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $listid );
            
            $qr = $this->db->query( $sql->toSQL() );
            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                if( is_array( $rows ) )
                {
                    $result = new SLPlayList( $this->db, $rows[0]['listid'] );
                }    
            }
            
            return $result;
        }
        
        
        function getAllPlayLists()
        {
            $qr = $this->db->query( "SELECT listid FROM playlists" );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLPlayList( $this->db, $row['listid'] ) );
                }    
            }
            
            return $result;
        }
    }
}
?>
