<?php

require_once( "core/db/objects/SLUserStats.php" );
require_once( "core/db/util/SQLStatement.php" );

if ( !defined( "_SL_USER_STATS_TABLE" ) ){
      define( "_SL_USER_STATS_TABLE", 1 );

    class SLUserStatsTable 
    {
        var $db;

        function SLUserStatsTable( $db )
        {
            $this->db = &$db;
        }

        
        function createUserStats( $uid  )
        {
            $template = "INSERT INTO stats_user ( uid,  streams, downloads ) VALUES ( ?, 0, 0 )";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        function deleteUserStatsForUID( $uid )
        {
            $template = "DELETE FROM stats_user WHERE uid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            
            $result = $this->db->query( $sql->toSQL() );
            return $result;
        }

        
        function removeStatsForUIDsNot( $uids )
        {
            $where_clause = "(";
            
            $count = count( $uids );
      
            for ( $i = 0; $i < $count; $i++ )
            {
                if ( $where_clause != "(" )
                {
                    $where_clause .= " OR ";
                }
                
                $where_clause .= "uid = ?";
            }

            $where_clause .= ")";

            $where = SQLStatement::createStatement( $where_clause );
            
            for ( $i = 0; $i < $count; $i++ )
            {
                $where->setValue( $i, $uids[$i] );
            }

            $where_sql = $where->toSQL();
            $sql = "DELETE FROM stats_user WHERE NOT $where_sql";
            $result = $this->db->query( $sql );

            return $result;
        }


        function getStatsForUser( $uid )
        {
            $result = null;
            
            $template = "SELECT uid FROM stats_user WHERE uid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                if ( is_array( $rows ) && count( $rows ) > 0 )
                {
                    $result = new SLUserStats( $this->db, $rows[0]['uid'] );
                }
            }

            return $result;
        }


        function statsExistForUser( $uid )
        {
            $result = false;
            
            $template = "SELECT uid FROM stats_user WHERE uid = ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $uid );
            
            $qr = $this->db->query( $sql->toSQL() );
            
            if ( $qr )
            {
                $rows = $this->db->getLastResult();
                $result = is_array( $rows ) && count( $rows ) > 0;
            }
            
            return $result; 
        }
            
               
        function getTopRankedUsersByDownloads( $num )
        {
            return $this->getHighestRankedUsers( "downloads", $num );
        } 
        
        function getTopRankedUsersByStreams( $num )
        {
            return $this->getHighestRankedUsers( "streams", $num );
        }
        
        function getHighestRankedUsers( $stat, $num, $offset = 0 )
        {
            $result = false;
            
            $template = "SELECT * FROM stats_user WHERE $stat > 0 ORDER BY $stat DESC LIMIT ? OFFSET ?";
            $sql = SQLStatement::createStatement( $template );
            $sql->setValue( 0, $num );
            $sql->setValue( 1, $offset );
            
            $qr = $this->db->query( $sql->toSQL() );

            if ( $qr )
            {
                $result = array();
                $rows = $this->db->getLastResult();
                
                foreach( $rows as $row )
                {
                    array_push( $result, new SLUserStats( $this->db, $row['uid'] ) );
                }    
            }
            
            return $result;
        }

        function getNumberOfRankedUsers( $stat )
        {
            $result = 0;

            $qr = $this->db->query( "SELECT COUNT(uid) FROM stats_user WHERE $stat > 0" );
            if ( $qr )
            {
                $last = $this->db->getLastResult();
                $result = array_pop( $last[0] );
            }
            else
            {
                $result = -1;
            }
            
            return $result;           
        }
    }
}
?>
