<?
require_once( "core/streamline_functions.php" );
require_once( "core/media_info/MediaInfoCache.php" );
require_once( "core/db/tables/SLMediaTable.php" );

if ( !defined( "_MEDIA_DB_MAINTAINER" ) ){
      define( "_MEDIA_DB_MAINTAINER", 1 );

    
    class MediaDBMaintainer
    {
        var $table;
        var $cache;
        var $testcount;
        var $media_root;
        var $root_len;
        var $pruned;

        function MediaDBMaintainer( $db, $media_root )
        {
            $this->table = new SLMediaTable( $db );
            $this->cache = new MediaInfoCache( $media_root );
            $this->media_root = $media_root;
            $this->root_len = strlen( $media_root );
        }
    
        function update()
        {
            $this->do_update( $this->media_root );
        }
        
        
        function do_update( $file )
        {
            set_time_limit( 20 );
            $dir = opendir( $file );
            
            while ( false !== ( $afile = readdir($dir) ) ) 
            {
                if( $afile == "." || $afile == ".." )
                {
                    continue;
                }

                $cur_file = joinFilePath( $file, $afile );

                if ( is_dir( $cur_file )  )
                {
                    $this->do_update( $cur_file ); 
                }
                else if ( is_file( $cur_file )  )
                {   
                    $tmp_array = explode( ".", $cur_file );
                    $ext = array_pop( $tmp_array );
                   
                    global $sl_media_types;
                    
                    if ( array_key_exists( $ext, $sl_media_types ) )
                    {
                        $rel_path = substr( $cur_file, $this->root_len - strlen( $cur_file ) );
                        $media = $this->table->getMediaByPath( $rel_path );
                        $info = $this->cache->getMediaInfo( $rel_path  );
                        
                        if ( $media == null )
                        {
                            echo "$rel_path not found in Media Database.  Creating...";
                            flush();
                            $result = $this->table->createMedia( $rel_path, $info->getTitle(), 
                                $info->getArtist(), $info->getAlbum(), 
                                $info->getGenre(), $info->getYear(), 
                                $info->getFileName(), $info->getModTime() );

                            if ( !$result )
                            {
                                echo "FAILED!<br>";
                            }
                            else
                            {
                                echo "Success.<br>";
                            }

                            flush();
                        }
                        else if ( $media->getModTime() + 0 < $info->getModTime() + 0 )
                        {
                            $ttime = $info->getModTime();
                            $mtime = $media->getModTime();
                            echo "$rel_path out of date (".date( "r", $ttime )." > ".date( "r", $mtime ).").  Updating...";
                            flush();
                            $media->setTitle( $info->getTitle() ); 
                            $media->setArtist( $info->getArtist() );
                            $media->setAlbum( $info->getAlbum() );
                            $media->setGenre( $info->getGenre() );
                            $media->setYear( $info->getYear() );
                            $media->setFileName( $info->getFileName() );
                            $media->setModTime( $info->getModTime() );

                            $media->store();
                            echo "Done.<br>";
                            flush();
                        }
                        else
                        {
                            echo "$rel_path OK<br>";
                            flush();
                        }
                    }
                }
            }
                                      
        }
        
        function prune()
        {
            $this->pruned = array();
            $this->do_prune( $this->media_root );
        }

        function do_prune( $file )
        {
            set_time_limit( 20 );
            $dir = opendir( $file );
            
            $page = 0;
            $count = 0;
            $chunk = 20;
            
            do
            {
                $media_array = $this->table->getAllMediaInRange( $chunk, $page );
                
                if ( is_array( $media_array ) )
                {
                    $count = count( $media_array );

                    for ( $i = 0; $i < $count; $i++ )
                    {
                        set_time_limit( 20 );
                        $media = $media_array[$i];

                        $rel_path = $media->getPath();
                        echo "Examining file: $rel_path... ";
                        
                        $media_path = joinFilePath( $this->media_root, $rel_path );

                        if ( !is_file( $media_path ) )
                        {
                            echo " &lt;Removed&gt; Deleting DB Entry.<br>";
                            $result = $this->table->deleteMedia( $rel_path );
                            array_push( $this->pruned, $rel_path );
                        }
                        else
                        {
                           echo " &lt;OK&gt;<br>";
                        }
                    }
                }
                else
                {
                    $count = 0;
                }

                $page++;
            }
            while( $count > 0 );
        }

        function getPruned()
        {
            return $this->pruned;
        }
    }
}
?>
