<?
require_once( "core/media_info/MediaInfoReader.php" );
require_once( "core/media_info/MediaInfoCacheFile.php" );
require_once( "core/streamline_functions.php" );

if ( !defined( "_MEDIA_INFO_CACHE" ) ){
      define( "_MEDIA_INFO_CACHE", 1 );

    
    class MediaInfoCache
    {
        var $cache_path;
        var $media_root;
        
        function MediaInfoCache( $media_root )
        {
            $this->media_root = $media_root;
            $this->cache_path = SL_ROOT.".media_info_cache/";
        }

        function getCachePath()
        {
            return $this->cache_path;
        }

        
        function & getMediaInfo( $media_path )
        {
            $media = joinFilePath( $this->media_root, $media_path );
            $cache = joinFilePath( $this->cache_path, $media_path );

            if ( !is_file( $media ) )
            {
                if ( is_file( $cache ) )
                {
                    unlink( $cache );
                }
            }
            else
            {
                if ( !is_file( $cache ) )
                {
                    $info = $this->createCache( $media, $media_path, $cache );
                }
                else
                {
                    //Check to see if the media has been modified since the cache was created.
                    
                    $media_mod = filemtime( $media );
                    $cache_mod = filemtime( $cache );

                    if ( $media_mod > $cache_mod )
                    {
                        $info = $this->createCache( $media, $media_path, $cache );
                    }
                }

                if ( !isset( $info ) )
                {
                    $info = $this->readCache( $cache );
                }
            }

            return $info;
        }

        
        function & readCache( $cache )
        {
            $file = file( $cache );

            $info = &new MediaInfoCacheFile( $file, filemtime( $cache ) );
        
            return $info;
        }
       

        function & createCache( $media_path, $rel_path, $cache_file )
        {
            $dir = dirname( $cache_file );

            if ( !is_dir( $dir ) )
            {
                $this->mkdirs( $dir );
            }
            
            $id3r = new MediaInfoReader( $media_path );
            $id3r->readMediaInfo();

            $cache = array( 
                $id3r->getArtist(),
                $id3r->getAlbum(),
                $id3r->getTitle(),
                $id3r->getTrack(),
                $id3r->getYear(),
                $id3r->getGenre(),
                $id3r->getBitrate(),
                $id3r->getSampleRate(),
                $id3r->getChannels(),
                $id3r->getLength(),
                $id3r->getSeconds(),
                $id3r->getFilename(),
                $id3r->getMimeType()
            );
            
            $file = fopen( $cache_file, "w" );
            fwrite( $file, implode( "\n", $cache ) );
            fclose( $file );

            $result = &new MediaInfoCacheFile( $cache, filemtime( $cache_file ) );

            return $result; 
        }
    

        function mkdirs($strPath, $mode = 770 )
        {
            if (is_dir($strPath)) return true;
        
            $pStrPath = dirname($strPath);
            if (!$this->mkdirs($pStrPath, $mode)) return false;
                return mkdir($strPath);
        }
    }
}
?>
